/** @component alert-banner */
import React from 'react';
import PropTypes from 'prop-types';
import { Icon } from "./..";

var AlertBanner = function AlertBanner(props) {
  var show = props.show,
      type = props.type,
      closable = props.closable,
      children = props.children,
      onHide = props.onHide;

  var handleKeyPress = function handleKeyPress(e) {
    e.preventDefault();

    if (e.which === 32 || e.which === 13) {
      return onHide(e);
    } else if (e.charCode === 32 || e.charCode === 13) {
      return onHide(e);
    }
  };

  return show && React.createElement("div", {
    type: type
  }, React.createElement("div", {
    className: "cui-alert-banner " + ("cui-alert-banner--" + type)
  }, React.createElement("div", {
    className: "cui-alert-banner__text"
  }, children), closable && React.createElement("div", {
    className: "cui-alert-banner__close",
    onClick: onHide,
    tabIndex: 0,
    onKeyPress: handleKeyPress,
    role: 'button'
  }, React.createElement(Icon, {
    name: "cancel_16"
  }))));
};

AlertBanner.defaultProps = {
  children: null,
  type: 'info',
  closable: false,
  onHide: function onHide() {}
};
AlertBanner.propTypes = {
  /** @prop Set AlertBanner visibility */
  show: PropTypes.bool.isRequired,

  /** @prop Children nodes to render inside AccordionHeader | null  */
  children: PropTypes.node,

  /** @prop Sets the AlertBanner type | 'info' */
  type: PropTypes.oneOf(['info', 'warning', 'error']),

  /** @prop Mandatory handler invoked when the user presses on the AlertBanner's close button or hit's the esc key | () => {} */
  onHide: PropTypes.func,

  /** @prop Sets the visibility of AlertBanner's close button | false */
  closable: PropTypes.bool
};
AlertBanner.displayName = 'AlertBanner';
export default AlertBanner;